import csv
import xml.etree.ElementTree as ET
import requests
from decimal import Decimal, ROUND_HALF_UP

# URL of the XML file
xml_url = 'https://dkkapusta1997.usermd.net/Jurek/action/feeds/action_allegro.xml'

# Define the output CSV file
csv_file = 'action.csv'

# Prefix for the product ID
#id_prefix = 'zielonalyzeczka_'

# Multiplier for the price
price_multiplier = Decimal('1.08')

# Download the XML file
response = requests.get(xml_url)
xml_data = response.content

# Parse the XML data
root = ET.fromstring(xml_data)

# Open the CSV file in write mode
with open(csv_file, 'w', newline='') as f:
    writer = csv.writer(f)

    # Write the header row
    writer.writerow(['sku', 'price', 'qty'])

    # Iterate over each 'o' element in the XML
    for product in root.findall('.//o'):

        # Extract the required data attributes
        product_id = product.get('id')
        price = Decimal(product.get('price')) * price_multiplier
        stock = product.get('stock')

        # Round the price to 2 decimal places
        price = price.quantize(Decimal('0.00'), rounding=ROUND_HALF_UP)

        # Set stock to 0 if it is 3 or less
        if stock is not None and int(stock) <= 3:
            stock = '0'

        # Write the data row
        writer.writerow([product_id, str(price), stock])

print(f"Product data extracted and saved to '{csv_file}'.")